@@ -56,19 +56,19 @@ const qreal pieceZValue = 1.0;
 const qreal legalMarkerZValue = 3.0;
 const qreal dragZValue = 4.0;
 
-const QString backgroundKey = QLatin1String ( "Background" );
-const QString whiteTileKey = QLatin1String ( "WhiteTile" );
-const QString blackTileKey = QLatin1String ( "BlackTile" );
-const QString legalMarkerKey = QLatin1String ( "Marker" );
-const QString motionMarkerKey = QLatin1String ( "Motion" );
-const QString dangerMarkerKey = QLatin1String ( "Danger" );
+const QString backgroundKey = QStringLiteral ( "Background" );
+const QString whiteTileKey = QStringLiteral ( "WhiteTile" );
+const QString blackTileKey = QStringLiteral ( "BlackTile" );
+const QString legalMarkerKey = QStringLiteral ( "Marker" );
+const QString motionMarkerKey = QStringLiteral ( "Motion" );
+const QString dangerMarkerKey = QStringLiteral ( "Danger" );
 
-const QString tbBorderKey = QLatin1String ( "TopBottomBorder" );
-const QString lrBorderKey = QLatin1String ( "LeftRightBorder" );
-const QString whiteLettersKey = QLatin1String ( "WhiteLetters" );
-const QString blackLettersKey = QLatin1String ( "BlackLetters" );
-const QString whiteNumbersKey = QLatin1String ( "WhiteNumbers" );
-const QString blackNumbersKey = QLatin1String ( "BlackNumbers" );
+const QString tbBorderKey = QStringLiteral ( "TopBottomBorder" );
+const QString lrBorderKey = QStringLiteral ( "LeftRightBorder" );
+const QString whiteLettersKey = QStringLiteral ( "WhiteLetters" );
+const QString blackLettersKey = QStringLiteral ( "BlackLetters" );
+const QString whiteNumbersKey = QStringLiteral ( "WhiteNumbers" );
+const QString blackNumbersKey = QStringLiteral ( "BlackNumbers" );
 
 Board::Board(KgThemeProvider* provider, QObject* parent) : QGraphicsScene(parent),
 	m_rules(nullptr),
@@ -154,14 +154,14 @@ void Board::movePiece(const Move& move) {
 		}
 		if ( Settings::showDanger() ) {
 			bool check = false;
-			for ( Piece* piece : m_grid ) {
+			for ( Piece* piece : qAsConst(m_grid) ) {
 				if ( piece->color() == m_currentPlayer && Manager::self()->rules()->isAttacking ( piece->boardPos() ) ) {
 					check = true;
 					addMarker ( piece->boardPos(), Danger );
 				}
 			}
 			if ( check ) {
-				for ( Piece* piece : m_grid ) {
+				for ( Piece* piece : qAsConst(m_grid) ) {
 					if ( piece->color() != m_currentPlayer && piece->pieceType() == King )
 						addMarker ( piece->boardPos(), Danger );
 				}
@@ -223,7 +223,7 @@ void Board::mousePressEvent(QGraphicsSceneMouseEvent* e) {
 				move.setFlag ( Move::Promote, true );
 				move.setPromotedType ( getPromotedType() );
 			}
-			emit pieceMoved(move);
+			Q_EMIT pieceMoved(move);
 			selectedPiece = nullptr;
 		}
 	} else {
@@ -242,7 +242,7 @@ void Board::mousePressEvent(QGraphicsSceneMouseEvent* e) {
 			}
 			d_piece->setZValue ( dragZValue );
 			if ( Settings::showMarker() ) {
-				for ( const Move& t_move : t_legalMoves )
+				for ( const Move& t_move : qAsConst(t_legalMoves) )
 					addMarker ( t_move.to(), LegalMove );
 			}
 			draggedPiece = d_piece;
@@ -299,7 +299,7 @@ void Board::dropEvent(QGraphicsSceneDragDropEvent* e) {
 				move.setFlag ( Move::Promote, true );
 				move.setPromotedType ( getPromotedType() );
 			}
-			emit pieceMoved(move);
+			Q_EMIT pieceMoved(move);
 		}
 		draggedPiece->setZValue(pieceZValue);
 		draggedPiece = nullptr;
@@ -387,7 +387,7 @@ void Board::setCurrentColor(Color color) {
 		m_displayedPlayer = nextPlayer;
 		changeDisplayedPlayer();
 	}
-	emit activePlayerChanged ( m_currentPlayer );
+	Q_EMIT activePlayerChanged ( m_currentPlayer );
 }
 
 
@@ -452,7 +452,7 @@ void Board::updateTheme() {
 		m_borders << tItem;
 
 		m_borders << new Item ( renderer, lrBorderKey, this, Pos() );
-		for ( Item* item : m_borders )
+		for ( Item* item : qAsConst(m_borders) )
 			item->setZValue ( borderZValue );
 	}
 	if ( m_displayNotations ) {
@@ -469,7 +469,7 @@ void Board::updateTheme() {
 		m_notations << new Item ( renderer, numbersKey, this, Pos() );
 		m_notations << new Item ( renderer, lettersKey, this, Pos() );
 		m_notations << new Item ( renderer, numbersKey, this, Pos() );
-		for ( Item* item : m_notations )
+		for ( Item* item : qAsConst(m_notations) )
 			item->setZValue ( notationZValue );
 	}
 	addTiles();
@@ -529,11 +529,11 @@ void Board::updateGraphics() {
 	QPointF bottomBorderPoint = m_boardRect.bottomLeft() - QPoint ( vBorderMargin, 0 );
 	QPointF leftBorderPoint = m_boardRect.topLeft() - QPoint ( vBorderMargin, 0 );
 
-	for ( Piece* p : m_grid )
+	for ( Piece* p : qAsConst(m_grid) )
 		centerAndResize ( p, tSize );
-	for ( Item* t : m_tiles )
+	for ( Item* t : qAsConst(m_tiles) )
 		centerAndResize ( t, tSize, Settings::animateBoard() );
-	for ( Item* t : markers )
+	for ( Item* t : qAsConst(markers) )
 		centerAndResize ( t, tSize );
 	if ( m_displayBorders ) {
 		m_borders[0]->moveAndResize ( bottomBorderPoint, m_tileSize, hBorderSize, Settings::animateBoard() );
@@ -550,12 +550,12 @@ void Board::updateGraphics() {
 }
 
 void Board::changeDisplayedPlayer() {
-	for ( Piece* p : m_grid )
+	for ( Piece* p : qAsConst(m_grid) )
 		centerOnPos ( p );
-	for ( Item* i : markers )
+	for ( Item* i : qAsConst(markers) )
 		centerOnPos ( i );
 	if ( Settings::animateBoard() ) {
-		for ( Item* i : m_tiles )
+		for ( Item* i : qAsConst(m_tiles) )
 			centerOnPos ( i );
 	}
 	if ( m_displayNotations ) {
@@ -571,7 +571,7 @@ void Board::changeDisplayedPlayer() {
 			m_notations[3]->setSpriteKey ( blackNumbersKey );
 		}
 	}
-	emit displayedPlayerChanged(m_displayedPlayer);
+	Q_EMIT displayedPlayerChanged(m_displayedPlayer);
 }
 
 PieceType Board::getPromotedType() {
